About CrunchyFrog
=================

CrunchyFrog was written by Andi Albrecht <albrecht.andi@gmail.com>.

To find more information about CrunchyFrog, please visit the
`project page <http://crunchyfrog.googlecode.com>`_ or post a message
on the `discussion group <http://groups.google.com/group/crunchyfrog>`_.

To report a bug or make a suggestion regarding this application or
this manual, file an issue on the
`issue tracker <http://code.google.com/p/crunchyfrog/issues/entry>`_.

This program is distributed under the terms of the GNU
General Public license as published by the Free Software
Foundation; either version 3 of the License, or (at your option)
any later version. A copy of this license can be found at
this `link <http://www.gnu.org/licenses/gpl.html>`_, or in the
file :file:`COPYING` included with the source code of this program.


Copyright (c)  2008 Andi Albrecht.

Permission is granted to copy, distribute and/or modify this document
under the terms of the GNU Free Documentation License, Version 1.3
or any later version published by the Free Software Foundation;
with no Invariant Sections, no Front-Cover Texts, and no Back-Cover Texts.

A copy of the license can be found at this
`page <http://www.gnu.org/copyleft/fdl.html>`_.

